==> zzyj-outputvalcount-api-3.0.0-20240626.080659-308-sources.jar: com/ejianc/business/outputvalcount/vo/ZcReportVO.java <==
package com.ejianc.business.outputvalcount.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * ZcReportEntity
 *
 * @author generator
 *
 */
public class ZcReportVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long billid; // 主键ID
    private String billcode; // 合同编码
    private String contractname; // 
    private Long tenantid; // 租户ID
    private Long partyid; // 甲方Id
    private String partyname; // 
    private Long projectid; // 项目Id
    private String projectname; // 
    private Long orgid; // 项目部Id
    private String orgname; // 
    private Long porgid; // 项目部上级组织Id
    private String porgname; //
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date signdate; // 签订日期
    private Long categoryid; // 合同类别Id
    private String categoryname; // 合同类别名称
    private Integer billstate; // 单据状态
    private Integer cardtype; // 合同类型：劳务合同-0，专业合同-1
    private Integer categorypid; // 
    private String categorypname; // 
    private BigDecimal basemny; // 原合同金额
    private BigDecimal contractmny; // 变更后金额
    private BigDecimal taxrate; // 合同税率
    private Long supplierid; // 供应商Id
    private String suppliername; // 
    private String statusid; // 合同履约状态：1、未签订；2、履约中；3、已封账；4、已解除；   默认为未签定，签章状态为已签章时，状态自动更改为【履约中】。当合同存在生效的最终结算时，状态自动改为【已封账】
    private Integer supplementflag; // 是否补充协议(1:是，0：否)
    private Long maincontractid; // 主合同Id
    private String statusname; // 	合同状态
    private BigDecimal sumlymny; // 累计履约金额
    private BigDecimal sumsettlemny; // 累计结算金额
    private BigDecimal finalsettlemny; // 最终结算金额
    private BigDecimal actualmny; // 累计实付金额
    private BigDecimal approvalmny; // 累计批复金额
    private Long contractId; // 合同id
    private BigDecimal finallymny;//履约终金额
    private BigDecimal finalconmny;//合同最终金额
    private BigDecimal actsalarymny;//工资实付金额
    private String filstatname;//归档状态	filstatName
    private BigDecimal appsalarymny;//工资支付总额    appSalaryMny
    //含工资累计批复总额    累计批复金额  +  工资支付总额
    //履约欠付金额  履约终金额  -  累计实付金额  -  工资实付金额
    //履约未结金额     累计履约金额  -  累计结算金额
    //结算欠付金额   累计结算金额  -  累计实付金额  -  工资实付金额
    //履约支付比例    ( 累计实付金额  +  工资实付金额   )  /  履约终金额
    //结算支付比例     (   累计实付金额  +  工资实付金额 )  /  累计结算金额
    //
    //
    //


    public String getFilstatname() {
        return filstatname;
    }

    public void setFilstatname(String filstatname) {
        this.filstatname = filstatname;
    }

    public BigDecimal getAppsalarymny() {
        return appsalarymny;
    }

    public void setAppsalarymny(BigDecimal appsalarymny) {
        this.appsalarymny = appsalarymny;
    }

    public BigDecimal getActsalarymny() {
        return actsalarymny;
    }

    public void setActsalarymny(BigDecimal actsalarymny) {
        this.actsalarymny = actsalarymny;
    }

    public BigDecimal getFinallymny() {
        return finallymny;
    }

    public void setFinallymny(BigDecimal finallymny) {
        this.finallymny = finallymny;
    }

    public BigDecimal getFinalconmny() {
        return finalconmny;
    }

    public void setFinalconmny(BigDecimal finalconmny) {
        this.finalconmny = finalconmny;
    }

    public Long getBillid() {
        return billid;
    }

    public void setBillid(Long billid) {
        this.billid = billid;
    }
    public String getBillcode() {
        return billcode;
    }

    public void setBillcode(String billcode) {
        this.billcode = billcode;
    }
    public String getContractname() {
        return contractname;
    }

    public void setContractname(String contractname) {
        this.contractname = contractname;
    }
    public Long getTenantid() {
        return tenantid;
    }

    public void setTenantid(Long tenantid) {
        this.tenantid = tenantid;
    }
    public Long getPartyid() {
        return partyid;
    }

    public void setPartyid(Long partyid) {
        this.partyid = partyid;
    }
    public String getPartyname() {
        return partyname;
    }

    public void setPartyname(String partyname) {
        this.partyname = partyname;
    }
    public Long getProjectid() {
        return projectid;
    }

    public void setProjectid(Long projectid) {
        this.projectid = projectid;
    }
    public String getProjectname() {
        return projectname;
    }

    public void setProjectname(String projectname) {
        this.projectname = projectname;
    }
    public Long getOrgid() {
        return orgid;
    }

    public void setOrgid(Long orgid) {
        this.orgid = orgid;
    }
    public String getOrgname() {
        return orgname;
    }

    public void setOrgname(String orgname) {
        this.orgname = orgname;
    }
    public Long getPorgid() {
        return porgid;
    }

    public void setPorgid(Long porgid) {
        this.porgid = porgid;
    }
    public String getPorgname() {
        return porgname;
    }

    public void setPorgname(String porgname) {
        this.porgname = porgname;
    }
    public Date getSigndate() {
        return signdate;
    }

    public void setSigndate(Date signdate) {
        this.signdate = signdate;
    }
    public Long getCategoryid() {
        return categoryid;
    }

    public void setCategoryid(Long categoryid) {
        this.categoryid = categoryid;
    }
    public String getCategoryname() {
        return categoryname;
    }

    public void setCategoryname(String categoryname) {
        this.categoryname = categoryname;
    }
    public Integer getBillstate() {
        return billstate;
    }

    public void setBillstate(Integer billstate) {
        this.billstate = billstate;
    }
    public Integer getCardtype() {
        return cardtype;
    }

    public void setCardtype(Integer cardtype) {
        this.cardtype = cardtype;
    }
    public Integer getCategorypid() {
        return categorypid;
    }

    public void setCategorypid(Integer categorypid) {
        this.categorypid = categorypid;
    }
    public String getCategorypname() {
        return categorypname;
    }

    public void setCategorypname(String categorypname) {
        this.categorypname = categorypname;
    }
    public BigDecimal getBasemny() {
        return basemny;
    }

    public void setBasemny(BigDecimal basemny) {
        this.basemny = basemny;
    }
    public BigDecimal getContractmny() {
        return contractmny;
    }

    public void setContractmny(BigDecimal contractmny) {
        this.contractmny = contractmny;
    }
    public BigDecimal getTaxrate() {
        return taxrate;
    }

    public void setTaxrate(BigDecimal taxrate) {
        this.taxrate = taxrate;
    }
    public Long getSupplierid() {
        return supplierid;
    }

    public void setSupplierid(Long supplierid) {
        this.supplierid = supplierid;
    }
    public String getSuppliername() {
        return suppliername;
    }

    public void setSuppliername(String suppliername) {
        this.suppliername = suppliername;
    }
    public String getStatusid() {
        return statusid;
    }

    public void setStatusid(String statusid) {
        this.statusid = statusid;
    }
    public Integer getSupplementflag() {
        return supplementflag;
    }

    public void setSupplementflag(Integer supplementflag) {
        this.supplementflag = supplementflag;
    }
    public Long getMaincontractid() {
        return maincontractid;
    }

    public void setMaincontractid(Long maincontractid) {
        this.maincontractid = maincontractid;
    }
    public String getStatusname() {
        return statusname;
    }

    public void setStatusname(String statusname) {
        this.statusname = statusname;
    }
    public BigDecimal getSumlymny() {
        return sumlymny;
    }

    public void setSumlymny(BigDecimal sumlymny) {
        this.sumlymny = sumlymny;
    }
    public BigDecimal getSumsettlemny() {
        return sumsettlemny;
    }

    public void setSumsettlemny(BigDecimal sumsettlemny) {
        this.sumsettlemny = sumsettlemny;
    }
    public BigDecimal getFinalsettlemny() {
        return finalsettlemny;
    }

    public void setFinalsettlemny(BigDecimal finalsettlemny) {
        this.finalsettlemny = finalsettlemny;
    }
    public BigDecimal getActualmny() {
        return actualmny;
    }

    public void setActualmny(BigDecimal actualmny) {
        this.actualmny = actualmny;
    }
    public BigDecimal getApprovalmny() {
        return approvalmny;
    }

    public void setApprovalmny(BigDecimal approvalmny) {
        this.approvalmny = approvalmny;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

}

==> zzyj-outputvalcount-api-3.0.0-20250611.235814-373-sources.jar: com/ejianc/business/outputvalcount/vo/ZcReportVO.java <==
package com.ejianc.business.outputvalcount.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * ZcReportEntity
 *
 * @author generator
 *
 */
public class ZcReportVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long billid; // 主键ID
    private String billcode; // 合同编码
    private String contractname; // 
    private Long tenantid; // 租户ID
    private Long partyid; // 甲方Id
    private String partyname; // 
    private Long projectid; // 项目Id
    private String projectname; // 
    private Long orgid; // 项目部Id
    private String orgname; // 
    private Long porgid; // 项目部上级组织Id
    private String porgname; //
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date signdate; // 签订日期
    private Long categoryid; // 合同类别Id
    private String categoryname; // 合同类别名称
    private Integer billstate; // 单据状态
    private Integer cardtype; // 合同类型：劳务合同-0，专业合同-1
    private Integer categorypid; // 
    private String categorypname; // 
    private BigDecimal basemny; // 原合同金额
    private BigDecimal contractmny; // 变更后金额
    private BigDecimal taxrate; // 合同税率
    private Long supplierid; // 供应商Id
    private String suppliername; // 
    private String statusid; // 合同履约状态：1、未签订；2、履约中；3、已封账；4、已解除；   默认为未签定，签章状态为已签章时，状态自动更改为【履约中】。当合同存在生效的最终结算时，状态自动改为【已封账】
    private Integer supplementflag; // 是否补充协议(1:是，0：否)
    private Long maincontractid; // 主合同Id
    private String statusname; // 	合同状态
    private BigDecimal sumlymny; // 累计履约金额
    private BigDecimal sumsettlemny; // 累计结算金额
    private BigDecimal finalsettlemny; // 最终结算金额
    private BigDecimal actualmny; // 累计实付金额
    private BigDecimal approvalmny; // 累计批复金额
    private Long contractId; // 合同id
    private BigDecimal finallymny;//履约终金额
    private BigDecimal finalconmny;//合同最终金额
    private BigDecimal actsalarymny;//工资实付金额
    private String filstatname;//归档状态	filstatName
    private BigDecimal appsalarymny;//工资支付总额    appSalaryMny
    //含工资累计批复总额    累计批复金额  +  工资支付总额
    //履约欠付金额  履约终金额  -  累计实付金额  -  工资实付金额
    //履约未结金额     累计履约金额  -  累计结算金额
    //结算欠付金额   累计结算金额  -  累计实付金额  -  工资实付金额
    //履约支付比例    ( 累计实付金额  +  工资实付金额   )  /  履约终金额
    //结算支付比例     (   累计实付金额  +  工资实付金额 )  /  累计结算金额
    //
    //
    //
    private BigDecimal actwithsalarymny;
    private BigDecimal jsqf;


    public BigDecimal getActwithsalarymny() {
        return actwithsalarymny;
    }

    public void setActwithsalarymny(BigDecimal actwithsalarymny) {
        this.actwithsalarymny = actwithsalarymny;
    }

    public BigDecimal getJsqf() {
        return jsqf;
    }

    public void setJsqf(BigDecimal jsqf) {
        this.jsqf = jsqf;
    }

    public String getFilstatname() {
        return filstatname;
    }

    public void setFilstatname(String filstatname) {
        this.filstatname = filstatname;
    }

    public BigDecimal getAppsalarymny() {
        return appsalarymny;
    }

    public void setAppsalarymny(BigDecimal appsalarymny) {
        this.appsalarymny = appsalarymny;
    }

    public BigDecimal getActsalarymny() {
        return actsalarymny;
    }

    public void setActsalarymny(BigDecimal actsalarymny) {
        this.actsalarymny = actsalarymny;
    }

    public BigDecimal getFinallymny() {
        return finallymny;
    }

    public void setFinallymny(BigDecimal finallymny) {
        this.finallymny = finallymny;
    }

    public BigDecimal getFinalconmny() {
        return finalconmny;
    }

    public void setFinalconmny(BigDecimal finalconmny) {
        this.finalconmny = finalconmny;
    }

    public Long getBillid() {
        return billid;
    }

    public void setBillid(Long billid) {
        this.billid = billid;
    }
    public String getBillcode() {
        return billcode;
    }

    public void setBillcode(String billcode) {
        this.billcode = billcode;
    }
    public String getContractname() {
        return contractname;
    }

    public void setContractname(String contractname) {
        this.contractname = contractname;
    }
    public Long getTenantid() {
        return tenantid;
    }

    public void setTenantid(Long tenantid) {
        this.tenantid = tenantid;
    }
    public Long getPartyid() {
        return partyid;
    }

    public void setPartyid(Long partyid) {
        this.partyid = partyid;
    }
    public String getPartyname() {
        return partyname;
    }

    public void setPartyname(String partyname) {
        this.partyname = partyname;
    }
    public Long getProjectid() {
        return projectid;
    }

    public void setProjectid(Long projectid) {
        this.projectid = projectid;
    }
    public String getProjectname() {
        return projectname;
    }

    public void setProjectname(String projectname) {
        this.projectname = projectname;
    }
    public Long getOrgid() {
        return orgid;
    }

    public void setOrgid(Long orgid) {
        this.orgid = orgid;
    }
    public String getOrgname() {
        return orgname;
    }

    public void setOrgname(String orgname) {
        this.orgname = orgname;
    }
    public Long getPorgid() {
        return porgid;
    }

    public void setPorgid(Long porgid) {
        this.porgid = porgid;
    }
    public String getPorgname() {
        return porgname;
    }

    public void setPorgname(String porgname) {
        this.porgname = porgname;
    }
    public Date getSigndate() {
        return signdate;
    }

    public void setSigndate(Date signdate) {
        this.signdate = signdate;
    }
    public Long getCategoryid() {
        return categoryid;
    }

    public void setCategoryid(Long categoryid) {
        this.categoryid = categoryid;
    }
    public String getCategoryname() {
        return categoryname;
    }

    public void setCategoryname(String categoryname) {
        this.categoryname = categoryname;
    }
    public Integer getBillstate() {
        return billstate;
    }

    public void setBillstate(Integer billstate) {
        this.billstate = billstate;
    }
    public Integer getCardtype() {
        return cardtype;
    }

    public void setCardtype(Integer cardtype) {
        this.cardtype = cardtype;
    }
    public Integer getCategorypid() {
        return categorypid;
    }

    public void setCategorypid(Integer categorypid) {
        this.categorypid = categorypid;
    }
    public String getCategorypname() {
        return categorypname;
    }

    public void setCategorypname(String categorypname) {
        this.categorypname = categorypname;
    }
    public BigDecimal getBasemny() {
        return basemny;
    }

    public void setBasemny(BigDecimal basemny) {
        this.basemny = basemny;
    }
    public BigDecimal getContractmny() {
        return contractmny;
    }

    public void setContractmny(BigDecimal contractmny) {
        this.contractmny = contractmny;
    }
    public BigDecimal getTaxrate() {
        return taxrate;
    }

    public void setTaxrate(BigDecimal taxrate) {
        this.taxrate = taxrate;
    }
    public Long getSupplierid() {
        return supplierid;
    }

    public void setSupplierid(Long supplierid) {
        this.supplierid = supplierid;
    }
    public String getSuppliername() {
        return suppliername;
    }

    public void setSuppliername(String suppliername) {
        this.suppliername = suppliername;
    }
    public String getStatusid() {
        return statusid;
    }

    public void setStatusid(String statusid) {
        this.statusid = statusid;
    }
    public Integer getSupplementflag() {
        return supplementflag;
    }

    public void setSupplementflag(Integer supplementflag) {
        this.supplementflag = supplementflag;
    }
    public Long getMaincontractid() {
        return maincontractid;
    }

    public void setMaincontractid(Long maincontractid) {
        this.maincontractid = maincontractid;
    }
    public String getStatusname() {
        return statusname;
    }

    public void setStatusname(String statusname) {
        this.statusname = statusname;
    }
    public BigDecimal getSumlymny() {
        return sumlymny;
    }

    public void setSumlymny(BigDecimal sumlymny) {
        this.sumlymny = sumlymny;
    }
    public BigDecimal getSumsettlemny() {
        return sumsettlemny;
    }

    public void setSumsettlemny(BigDecimal sumsettlemny) {
        this.sumsettlemny = sumsettlemny;
    }
    public BigDecimal getFinalsettlemny() {
        return finalsettlemny;
    }

    public void setFinalsettlemny(BigDecimal finalsettlemny) {
        this.finalsettlemny = finalsettlemny;
    }
    public BigDecimal getActualmny() {
        return actualmny;
    }

    public void setActualmny(BigDecimal actualmny) {
        this.actualmny = actualmny;
    }
    public BigDecimal getApprovalmny() {
        return approvalmny;
    }

    public void setApprovalmny(BigDecimal approvalmny) {
        this.approvalmny = approvalmny;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

}
